pub struct AddInsuranceFundStake {
pub state: Pubkey,
pub spot_market: Pubkey,
pub insurance_fund_stake: Pubkey,
pub user_stats: Pubkey,
pub authority: Pubkey,
pub spot_market_vault: Pubkey,
pub insurance_fund_vault: Pubkey,
pub drift_signer: Pubkey,
pub user_token_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for AddInsuranceFundStake.
Fields
state: Pubkeyspot_market: Pubkeyinsurance_fund_stake: Pubkeyuser_stats: Pubkeyspot_market_vault: Pubkeyinsurance_fund_vault: Pubkeydrift_signer: Pubkeyuser_token_account: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddInsuranceFundStakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddInsuranceFundStakewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddInsuranceFundStake
impl ToAccountMetas for AddInsuranceFundStake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddInsuranceFundStake
impl RefUnwindSafe for AddInsuranceFundStake
impl Send for AddInsuranceFundStake
impl Sync for AddInsuranceFundStake
impl Unpin for AddInsuranceFundStake
impl UnwindSafe for AddInsuranceFundStake