pub struct AdminRemoveInsuranceFundStake {
pub admin: Pubkey,
pub state: Pubkey,
pub spot_market: Pubkey,
pub insurance_fund_vault: Pubkey,
pub drift_signer: Pubkey,
pub admin_token_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for AdminRemoveInsuranceFundStake.
Fields
admin: Pubkeystate: Pubkeyspot_market: Pubkeyinsurance_fund_vault: Pubkeydrift_signer: Pubkeyadmin_token_account: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AdminRemoveInsuranceFundStakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for AdminRemoveInsuranceFundStakewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AdminRemoveInsuranceFundStake
impl ToAccountMetas for AdminRemoveInsuranceFundStake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AdminRemoveInsuranceFundStake
impl RefUnwindSafe for AdminRemoveInsuranceFundStake
impl Send for AdminRemoveInsuranceFundStake
impl Sync for AdminRemoveInsuranceFundStake
impl Unpin for AdminRemoveInsuranceFundStake
impl UnwindSafe for AdminRemoveInsuranceFundStake