pub struct CancelRequestRemoveInsuranceFundStake {
pub spot_market: Pubkey,
pub insurance_fund_stake: Pubkey,
pub user_stats: Pubkey,
pub authority: Pubkey,
pub insurance_fund_vault: Pubkey,
}Expand description
Generated client accounts for CancelRequestRemoveInsuranceFundStake.
Fields
spot_market: Pubkeyinsurance_fund_stake: Pubkeyuser_stats: Pubkeyinsurance_fund_vault: PubkeyTrait Implementations
Sourceimpl ToAccountMetas for CancelRequestRemoveInsuranceFundStake
impl ToAccountMetas for CancelRequestRemoveInsuranceFundStake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CancelRequestRemoveInsuranceFundStake
impl RefUnwindSafe for CancelRequestRemoveInsuranceFundStake
impl Send for CancelRequestRemoveInsuranceFundStake
impl Sync for CancelRequestRemoveInsuranceFundStake
impl Unpin for CancelRequestRemoveInsuranceFundStake
impl UnwindSafe for CancelRequestRemoveInsuranceFundStake