pub struct DeleteUser {
pub user: Pubkey,
pub user_stats: Pubkey,
pub state: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for DeleteUser.
Fields
user: Pubkeyuser_stats: Pubkeystate: PubkeyTrait Implementations
Sourceimpl BorshSerialize for DeleteUserwhere
Pubkey: BorshSerialize,
impl BorshSerialize for DeleteUserwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for DeleteUser
impl ToAccountMetas for DeleteUser
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for DeleteUser
impl RefUnwindSafe for DeleteUser
impl Send for DeleteUser
impl Sync for DeleteUser
impl Unpin for DeleteUser
impl UnwindSafe for DeleteUser