pub struct InitializeInsuranceFundStake {
pub spot_market: Pubkey,
pub insurance_fund_stake: Pubkey,
pub user_stats: Pubkey,
pub state: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub rent: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializeInsuranceFundStake.
Fields
spot_market: Pubkeyinsurance_fund_stake: Pubkeyuser_stats: Pubkeystate: Pubkeypayer: Pubkeyrent: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeInsuranceFundStakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeInsuranceFundStakewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializeInsuranceFundStake
impl ToAccountMetas for InitializeInsuranceFundStake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeInsuranceFundStake
impl RefUnwindSafe for InitializeInsuranceFundStake
impl Send for InitializeInsuranceFundStake
impl Sync for InitializeInsuranceFundStake
impl Unpin for InitializeInsuranceFundStake
impl UnwindSafe for InitializeInsuranceFundStake