pub struct InitializeUser {
pub user: Pubkey,
pub user_stats: Pubkey,
pub state: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub rent: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializeUser.
Fields
user: Pubkeyuser_stats: Pubkeystate: Pubkeypayer: Pubkeyrent: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeUserwhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeUserwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializeUser
impl ToAccountMetas for InitializeUser
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeUser
impl RefUnwindSafe for InitializeUser
impl Send for InitializeUser
impl Sync for InitializeUser
impl Unpin for InitializeUser
impl UnwindSafe for InitializeUser