pub struct ModifyOrder {
pub state: Pubkey,
pub user: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for ModifyOrder.
Fields
state: Pubkeyuser: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ModifyOrderwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ModifyOrderwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ModifyOrder
impl ToAccountMetas for ModifyOrder
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ModifyOrder
impl RefUnwindSafe for ModifyOrder
impl Send for ModifyOrder
impl Sync for ModifyOrder
impl Unpin for ModifyOrder
impl UnwindSafe for ModifyOrder