pub struct ModifyOrderByUserId {
pub state: Pubkey,
pub user: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for ModifyOrderByUserId.
Fields
state: Pubkeyuser: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ModifyOrderByUserIdwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ModifyOrderByUserIdwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ModifyOrderByUserId
impl ToAccountMetas for ModifyOrderByUserId
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ModifyOrderByUserId
impl RefUnwindSafe for ModifyOrderByUserId
impl Send for ModifyOrderByUserId
impl Sync for ModifyOrderByUserId
impl Unpin for ModifyOrderByUserId
impl UnwindSafe for ModifyOrderByUserId