pub struct RemoveInsuranceFundStake {
pub state: Pubkey,
pub spot_market: Pubkey,
pub insurance_fund_stake: Pubkey,
pub user_stats: Pubkey,
pub authority: Pubkey,
pub insurance_fund_vault: Pubkey,
pub drift_signer: Pubkey,
pub user_token_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for RemoveInsuranceFundStake.
Fields
state: Pubkeyspot_market: Pubkeyinsurance_fund_stake: Pubkeyuser_stats: Pubkeyinsurance_fund_vault: Pubkeydrift_signer: Pubkeyuser_token_account: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for RemoveInsuranceFundStakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for RemoveInsuranceFundStakewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for RemoveInsuranceFundStake
impl ToAccountMetas for RemoveInsuranceFundStake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for RemoveInsuranceFundStake
impl RefUnwindSafe for RemoveInsuranceFundStake
impl Send for RemoveInsuranceFundStake
impl Sync for RemoveInsuranceFundStake
impl Unpin for RemoveInsuranceFundStake
impl UnwindSafe for RemoveInsuranceFundStake