pub struct ResolvePerpPnlDeficit {
pub state: Pubkey,
pub authority: Pubkey,
pub spot_market_vault: Pubkey,
pub insurance_fund_vault: Pubkey,
pub drift_signer: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for ResolvePerpPnlDeficit.
Fields
state: Pubkeyspot_market_vault: Pubkeyinsurance_fund_vault: Pubkeydrift_signer: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ResolvePerpPnlDeficitwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ResolvePerpPnlDeficitwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ResolvePerpPnlDeficit
impl ToAccountMetas for ResolvePerpPnlDeficit
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ResolvePerpPnlDeficit
impl RefUnwindSafe for ResolvePerpPnlDeficit
impl Send for ResolvePerpPnlDeficit
impl Sync for ResolvePerpPnlDeficit
impl Unpin for ResolvePerpPnlDeficit
impl UnwindSafe for ResolvePerpPnlDeficit