pub struct UpdateLiquidationDuration {
pub admin: Pubkey,
pub state: Pubkey,
}Expand description
Generated client accounts for UpdateLiquidationDuration.
Fields
admin: Pubkeystate: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateLiquidationDurationwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateLiquidationDurationwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateLiquidationDuration
impl ToAccountMetas for UpdateLiquidationDuration
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateLiquidationDuration
impl RefUnwindSafe for UpdateLiquidationDuration
impl Send for UpdateLiquidationDuration
impl Sync for UpdateLiquidationDuration
impl Unpin for UpdateLiquidationDuration
impl UnwindSafe for UpdateLiquidationDuration