pub struct UpdateOracleGuardRails {
pub admin: Pubkey,
pub state: Pubkey,
}Expand description
Generated client accounts for UpdateOracleGuardRails.
Fields
admin: Pubkeystate: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateOracleGuardRailswhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateOracleGuardRailswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateOracleGuardRails
impl ToAccountMetas for UpdateOracleGuardRails
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateOracleGuardRails
impl RefUnwindSafe for UpdateOracleGuardRails
impl Send for UpdateOracleGuardRails
impl Sync for UpdateOracleGuardRails
impl Unpin for UpdateOracleGuardRails
impl UnwindSafe for UpdateOracleGuardRails