pub struct UpdatePerpFeeStructure {
pub admin: Pubkey,
pub state: Pubkey,
}Expand description
Generated client accounts for UpdatePerpFeeStructure.
Fields
admin: Pubkeystate: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdatePerpFeeStructurewhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdatePerpFeeStructurewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdatePerpFeeStructure
impl ToAccountMetas for UpdatePerpFeeStructure
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdatePerpFeeStructure
impl RefUnwindSafe for UpdatePerpFeeStructure
impl Send for UpdatePerpFeeStructure
impl Sync for UpdatePerpFeeStructure
impl Unpin for UpdatePerpFeeStructure
impl UnwindSafe for UpdatePerpFeeStructure