pub struct UpdateUserDelegate {
pub user: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for UpdateUserDelegate.
Fields
user: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateUserDelegatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateUserDelegatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateUserDelegate
impl ToAccountMetas for UpdateUserDelegate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateUserDelegate
impl RefUnwindSafe for UpdateUserDelegate
impl Send for UpdateUserDelegate
impl Sync for UpdateUserDelegate
impl Unpin for UpdateUserDelegate
impl UnwindSafe for UpdateUserDelegate