pub struct UpdateUserName {
pub user: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for UpdateUserName.
Fields
user: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateUserNamewhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateUserNamewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateUserName
impl ToAccountMetas for UpdateUserName
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateUserName
impl RefUnwindSafe for UpdateUserName
impl Send for UpdateUserName
impl Sync for UpdateUserName
impl Unpin for UpdateUserName
impl UnwindSafe for UpdateUserName