pub struct UpdateUserOpenOrdersCount {
pub state: Pubkey,
pub authority: Pubkey,
pub filler: Pubkey,
pub user: Pubkey,
}Expand description
Generated client accounts for UpdateUserOpenOrdersCount.
Fields
state: Pubkeyfiller: Pubkeyuser: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateUserOpenOrdersCountwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateUserOpenOrdersCountwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateUserOpenOrdersCount
impl ToAccountMetas for UpdateUserOpenOrdersCount
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateUserOpenOrdersCount
impl RefUnwindSafe for UpdateUserOpenOrdersCount
impl Send for UpdateUserOpenOrdersCount
impl Sync for UpdateUserOpenOrdersCount
impl Unpin for UpdateUserOpenOrdersCount
impl UnwindSafe for UpdateUserOpenOrdersCount