pub struct UpdateUserQuoteAssetInsuranceStake {
pub state: Pubkey,
pub spot_market: Pubkey,
pub insurance_fund_stake: Pubkey,
pub user_stats: Pubkey,
pub authority: Pubkey,
pub insurance_fund_vault: Pubkey,
}Expand description
Generated client accounts for UpdateUserQuoteAssetInsuranceStake.
Fields
state: Pubkeyspot_market: Pubkeyinsurance_fund_stake: Pubkeyuser_stats: Pubkeyinsurance_fund_vault: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateUserQuoteAssetInsuranceStakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateUserQuoteAssetInsuranceStakewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateUserQuoteAssetInsuranceStake
impl ToAccountMetas for UpdateUserQuoteAssetInsuranceStake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateUserQuoteAssetInsuranceStake
impl RefUnwindSafe for UpdateUserQuoteAssetInsuranceStake
impl Send for UpdateUserQuoteAssetInsuranceStake
impl Sync for UpdateUserQuoteAssetInsuranceStake
impl Unpin for UpdateUserQuoteAssetInsuranceStake
impl UnwindSafe for UpdateUserQuoteAssetInsuranceStake