pub struct UpdateWithdrawGuardThreshold {
pub admin: Pubkey,
pub state: Pubkey,
pub spot_market: Pubkey,
}Expand description
Generated client accounts for UpdateWithdrawGuardThreshold.
Fields
admin: Pubkeystate: Pubkeyspot_market: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateWithdrawGuardThresholdwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateWithdrawGuardThresholdwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateWithdrawGuardThreshold
impl ToAccountMetas for UpdateWithdrawGuardThreshold
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateWithdrawGuardThreshold
impl RefUnwindSafe for UpdateWithdrawGuardThreshold
impl Send for UpdateWithdrawGuardThreshold
impl Sync for UpdateWithdrawGuardThreshold
impl Unpin for UpdateWithdrawGuardThreshold
impl UnwindSafe for UpdateWithdrawGuardThreshold