pub struct EndSwap {
pub _in_market_index: u16,
pub _out_market_index: u16,
pub _limit_price: Option<u64>,
pub _reduce_only: Option<SwapReduceOnly>,
}Expand description
Instruction.
Fields
_in_market_index: u16_out_market_index: u16_limit_price: Option<u64>_reduce_only: Option<SwapReduceOnly>Trait Implementations
Sourceimpl BorshDeserialize for EndSwapwhere
u16: BorshDeserialize,
Option<u64>: BorshDeserialize,
Option<SwapReduceOnly>: BorshDeserialize,
impl BorshDeserialize for EndSwapwhere
u16: BorshDeserialize,
Option<u64>: BorshDeserialize,
Option<SwapReduceOnly>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for EndSwap
impl BorshSerialize for EndSwap
Sourceimpl Discriminator for EndSwap
impl Discriminator for EndSwap
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for EndSwap
impl InstructionData for EndSwap