pub struct InitializeSpotMarket {
pub _optimal_utilization: u32,
pub _optimal_borrow_rate: u32,
pub _max_borrow_rate: u32,
pub _oracle_source: OracleSource,
pub _initial_asset_weight: u32,
pub _maintenance_asset_weight: u32,
pub _initial_liability_weight: u32,
pub _maintenance_liability_weight: u32,
pub _imf_factor: u32,
pub _liquidator_fee: u32,
pub _active_status: bool,
pub _name: [u8; 32],
}Expand description
Instruction.
Fields
_optimal_utilization: u32_optimal_borrow_rate: u32_max_borrow_rate: u32_oracle_source: OracleSource_initial_asset_weight: u32_maintenance_asset_weight: u32_initial_liability_weight: u32_maintenance_liability_weight: u32_imf_factor: u32_liquidator_fee: u32_active_status: bool_name: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for InitializeSpotMarketwhere
u32: BorshDeserialize,
OracleSource: BorshDeserialize,
bool: BorshDeserialize,
[u8; 32]: BorshDeserialize,
impl BorshDeserialize for InitializeSpotMarketwhere
u32: BorshDeserialize,
OracleSource: BorshDeserialize,
bool: BorshDeserialize,
[u8; 32]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitializeSpotMarketwhere
u32: BorshSerialize,
OracleSource: BorshSerialize,
bool: BorshSerialize,
[u8; 32]: BorshSerialize,
impl BorshSerialize for InitializeSpotMarketwhere
u32: BorshSerialize,
OracleSource: BorshSerialize,
bool: BorshSerialize,
[u8; 32]: BorshSerialize,
Sourceimpl Discriminator for InitializeSpotMarket
impl Discriminator for InitializeSpotMarket
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more