pub struct LiquidatePerp {
pub _market_index: u16,
pub _liquidator_max_base_asset_amount: u64,
pub _limit_price: Option<u64>,
}Expand description
Instruction.
Fields
_market_index: u16_liquidator_max_base_asset_amount: u64_limit_price: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for LiquidatePerp
impl BorshDeserialize for LiquidatePerp
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for LiquidatePerp
impl BorshSerialize for LiquidatePerp
Sourceimpl Discriminator for LiquidatePerp
impl Discriminator for LiquidatePerp
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for LiquidatePerp
impl InstructionData for LiquidatePerp