pub struct ModifyOrder {
pub _order_id: Option<u32>,
pub _modify_order_params: ModifyOrderParams,
}Expand description
Instruction.
Fields
_order_id: Option<u32>_modify_order_params: ModifyOrderParamsTrait Implementations
Sourceimpl BorshDeserialize for ModifyOrder
impl BorshDeserialize for ModifyOrder
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ModifyOrder
impl BorshSerialize for ModifyOrder
Sourceimpl Discriminator for ModifyOrder
impl Discriminator for ModifyOrder
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for ModifyOrder
impl InstructionData for ModifyOrder