pub struct ModifyOrderByUserId {
pub _user_order_id: u8,
pub _modify_order_params: ModifyOrderParams,
}Expand description
Instruction.
Fields
_user_order_id: u8_modify_order_params: ModifyOrderParamsTrait Implementations
Sourceimpl BorshDeserialize for ModifyOrderByUserId
impl BorshDeserialize for ModifyOrderByUserId
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ModifyOrderByUserId
impl BorshSerialize for ModifyOrderByUserId
Sourceimpl Discriminator for ModifyOrderByUserId
impl Discriminator for ModifyOrderByUserId
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more