pub struct MoveAmmPrice {
pub _base_asset_reserve: u128,
pub _quote_asset_reserve: u128,
pub _sqrt_k: u128,
}Expand description
Instruction.
Fields
_base_asset_reserve: u128_quote_asset_reserve: u128_sqrt_k: u128Trait Implementations
Sourceimpl BorshDeserialize for MoveAmmPricewhere
u128: BorshDeserialize,
impl BorshDeserialize for MoveAmmPricewhere
u128: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MoveAmmPricewhere
u128: BorshSerialize,
impl BorshSerialize for MoveAmmPricewhere
u128: BorshSerialize,
Sourceimpl Discriminator for MoveAmmPrice
impl Discriminator for MoveAmmPrice
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for MoveAmmPrice
impl InstructionData for MoveAmmPrice