pub struct PlaceAndTakePerpOrder {
pub _params: OrderParams,
pub _maker_order_id: Option<u32>,
}Expand description
Instruction.
Fields
_params: OrderParams_maker_order_id: Option<u32>Trait Implementations
Sourceimpl BorshDeserialize for PlaceAndTakePerpOrder
impl BorshDeserialize for PlaceAndTakePerpOrder
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for PlaceAndTakePerpOrder
impl Discriminator for PlaceAndTakePerpOrder
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more