pub struct SettleRevenueToInsuranceFund {
pub _spot_market_index: u16,
}Expand description
Instruction.
Fields
_spot_market_index: u16Trait Implementations
Sourceimpl BorshDeserialize for SettleRevenueToInsuranceFundwhere
u16: BorshDeserialize,
impl BorshDeserialize for SettleRevenueToInsuranceFundwhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SettleRevenueToInsuranceFundwhere
u16: BorshSerialize,
impl BorshSerialize for SettleRevenueToInsuranceFundwhere
u16: BorshSerialize,
Sourceimpl Discriminator for SettleRevenueToInsuranceFund
impl Discriminator for SettleRevenueToInsuranceFund
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more