pub struct TransferDeposit {
pub _market_index: u16,
pub _amount: u64,
}Expand description
Instruction.
Fields
_market_index: u16_amount: u64Trait Implementations
Sourceimpl BorshDeserialize for TransferDeposit
impl BorshDeserialize for TransferDeposit
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TransferDeposit
impl BorshSerialize for TransferDeposit
Sourceimpl Discriminator for TransferDeposit
impl Discriminator for TransferDeposit
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for TransferDeposit
impl InstructionData for TransferDeposit