pub struct UpdateAdmin {
pub _admin: Pubkey,
}Expand description
Instruction.
Fields
_admin: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for UpdateAdminwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for UpdateAdminwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateAdminwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateAdminwhere
Pubkey: BorshSerialize,
Sourceimpl Discriminator for UpdateAdmin
impl Discriminator for UpdateAdmin
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateAdmin
impl InstructionData for UpdateAdmin