pub struct UpdateAmmJitIntensity {
pub _amm_jit_intensity: u8,
}Expand description
Instruction.
Fields
_amm_jit_intensity: u8Trait Implementations
Sourceimpl BorshDeserialize for UpdateAmmJitIntensitywhere
u8: BorshDeserialize,
impl BorshDeserialize for UpdateAmmJitIntensitywhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateAmmJitIntensitywhere
u8: BorshSerialize,
impl BorshSerialize for UpdateAmmJitIntensitywhere
u8: BorshSerialize,
Sourceimpl Discriminator for UpdateAmmJitIntensity
impl Discriminator for UpdateAmmJitIntensity
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more