pub struct UpdateAmms {
pub _market_indexes: [u16; 5],
}Expand description
Instruction.
Fields
_market_indexes: [u16; 5]Trait Implementations
Sourceimpl BorshDeserialize for UpdateAmms
impl BorshDeserialize for UpdateAmms
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateAmms
impl BorshSerialize for UpdateAmms
Sourceimpl Discriminator for UpdateAmms
impl Discriminator for UpdateAmms
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateAmms
impl InstructionData for UpdateAmms