pub struct UpdateDiscountMint {
pub _discount_mint: Pubkey,
}Expand description
Instruction.
Fields
_discount_mint: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for UpdateDiscountMintwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for UpdateDiscountMintwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateDiscountMintwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateDiscountMintwhere
Pubkey: BorshSerialize,
Sourceimpl Discriminator for UpdateDiscountMint
impl Discriminator for UpdateDiscountMint
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateDiscountMint
impl InstructionData for UpdateDiscountMint