pub struct UpdateInsuranceFundUnstakingPeriod {
pub _insurance_fund_unstaking_period: i64,
}Expand description
Instruction.
Fields
_insurance_fund_unstaking_period: i64Trait Implementations
Sourceimpl BorshDeserialize for UpdateInsuranceFundUnstakingPeriodwhere
i64: BorshDeserialize,
impl BorshDeserialize for UpdateInsuranceFundUnstakingPeriodwhere
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateInsuranceFundUnstakingPeriodwhere
i64: BorshSerialize,
impl BorshSerialize for UpdateInsuranceFundUnstakingPeriodwhere
i64: BorshSerialize,
Sourceimpl Discriminator for UpdateInsuranceFundUnstakingPeriod
impl Discriminator for UpdateInsuranceFundUnstakingPeriod
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more