pub struct UpdateK {
pub _sqrt_k: u128,
}Expand description
Instruction.
Fields
_sqrt_k: u128Trait Implementations
Sourceimpl BorshDeserialize for UpdateKwhere
u128: BorshDeserialize,
impl BorshDeserialize for UpdateKwhere
u128: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateKwhere
u128: BorshSerialize,
impl BorshSerialize for UpdateKwhere
u128: BorshSerialize,
Sourceimpl Discriminator for UpdateK
impl Discriminator for UpdateK
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateK
impl InstructionData for UpdateK