pub struct UpdatePerpFeeStructure {
pub _fee_structure: FeeStructure,
}Expand description
Instruction.
Fields
_fee_structure: FeeStructureTrait Implementations
Sourceimpl BorshDeserialize for UpdatePerpFeeStructurewhere
FeeStructure: BorshDeserialize,
impl BorshDeserialize for UpdatePerpFeeStructurewhere
FeeStructure: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdatePerpFeeStructurewhere
FeeStructure: BorshSerialize,
impl BorshSerialize for UpdatePerpFeeStructurewhere
FeeStructure: BorshSerialize,
Sourceimpl Discriminator for UpdatePerpFeeStructure
impl Discriminator for UpdatePerpFeeStructure
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more