pub struct UpdatePerpMarketMaxOpenInterest {
pub _max_open_interest: u128,
}Expand description
Instruction.
Fields
_max_open_interest: u128Trait Implementations
Sourceimpl BorshDeserialize for UpdatePerpMarketMaxOpenInterestwhere
u128: BorshDeserialize,
impl BorshDeserialize for UpdatePerpMarketMaxOpenInterestwhere
u128: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdatePerpMarketMaxOpenInterestwhere
u128: BorshSerialize,
impl BorshSerialize for UpdatePerpMarketMaxOpenInterestwhere
u128: BorshSerialize,
Sourceimpl Discriminator for UpdatePerpMarketMaxOpenInterest
impl Discriminator for UpdatePerpMarketMaxOpenInterest
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more