pub struct UpdatePerpMarketMaxSpread {
pub _max_spread: u32,
}Expand description
Instruction.
Fields
_max_spread: u32Trait Implementations
Sourceimpl BorshDeserialize for UpdatePerpMarketMaxSpreadwhere
u32: BorshDeserialize,
impl BorshDeserialize for UpdatePerpMarketMaxSpreadwhere
u32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdatePerpMarketMaxSpreadwhere
u32: BorshSerialize,
impl BorshSerialize for UpdatePerpMarketMaxSpreadwhere
u32: BorshSerialize,
Sourceimpl Discriminator for UpdatePerpMarketMaxSpread
impl Discriminator for UpdatePerpMarketMaxSpread
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more