pub struct UpdatePerpMarketOracle {
pub _oracle: Pubkey,
pub _oracle_source: OracleSource,
}Expand description
Instruction.
Fields
_oracle: Pubkey_oracle_source: OracleSourceTrait Implementations
Sourceimpl BorshDeserialize for UpdatePerpMarketOracle
impl BorshDeserialize for UpdatePerpMarketOracle
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for UpdatePerpMarketOracle
impl Discriminator for UpdatePerpMarketOracle
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more