pub struct UpdateSpotAuctionDuration {
pub _default_spot_auction_duration: u8,
}Expand description
Instruction.
Fields
_default_spot_auction_duration: u8Trait Implementations
Sourceimpl BorshDeserialize for UpdateSpotAuctionDurationwhere
u8: BorshDeserialize,
impl BorshDeserialize for UpdateSpotAuctionDurationwhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateSpotAuctionDurationwhere
u8: BorshSerialize,
impl BorshSerialize for UpdateSpotAuctionDurationwhere
u8: BorshSerialize,
Sourceimpl Discriminator for UpdateSpotAuctionDuration
impl Discriminator for UpdateSpotAuctionDuration
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more