pub struct UpdateSpotFeeStructure {
pub _fee_structure: FeeStructure,
}Expand description
Instruction.
Fields
_fee_structure: FeeStructureTrait Implementations
Sourceimpl BorshDeserialize for UpdateSpotFeeStructurewhere
FeeStructure: BorshDeserialize,
impl BorshDeserialize for UpdateSpotFeeStructurewhere
FeeStructure: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateSpotFeeStructurewhere
FeeStructure: BorshSerialize,
impl BorshSerialize for UpdateSpotFeeStructurewhere
FeeStructure: BorshSerialize,
Sourceimpl Discriminator for UpdateSpotFeeStructure
impl Discriminator for UpdateSpotFeeStructure
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more