pub struct UpdateUserMarginTradingEnabled {
pub _sub_account_id: u16,
pub _margin_trading_enabled: bool,
}Expand description
Instruction.
Fields
_sub_account_id: u16_margin_trading_enabled: boolTrait Implementations
Sourceimpl BorshDeserialize for UpdateUserMarginTradingEnabled
impl BorshDeserialize for UpdateUserMarginTradingEnabled
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for UpdateUserMarginTradingEnabled
impl Discriminator for UpdateUserMarginTradingEnabled
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more