pub struct UpdateUserName {
pub _sub_account_id: u16,
pub _name: [u8; 32],
}Expand description
Instruction.
Fields
_sub_account_id: u16_name: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for UpdateUserName
impl BorshDeserialize for UpdateUserName
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateUserName
impl BorshSerialize for UpdateUserName
Sourceimpl Discriminator for UpdateUserName
impl Discriminator for UpdateUserName
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateUserName
impl InstructionData for UpdateUserName