pub struct UpdateWithdrawGuardThreshold {
pub _withdraw_guard_threshold: u64,
}Expand description
Instruction.
Fields
_withdraw_guard_threshold: u64Trait Implementations
Sourceimpl BorshDeserialize for UpdateWithdrawGuardThresholdwhere
u64: BorshDeserialize,
impl BorshDeserialize for UpdateWithdrawGuardThresholdwhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateWithdrawGuardThresholdwhere
u64: BorshSerialize,
impl BorshSerialize for UpdateWithdrawGuardThresholdwhere
u64: BorshSerialize,
Sourceimpl Discriminator for UpdateWithdrawGuardThreshold
impl Discriminator for UpdateWithdrawGuardThreshold
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more