pub struct Withdraw {
pub _market_index: u16,
pub _amount: u64,
pub _reduce_only: bool,
}Expand description
Instruction.
Fields
_market_index: u16_amount: u64_reduce_only: boolTrait Implementations
Sourceimpl BorshDeserialize for Withdraw
impl BorshDeserialize for Withdraw
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Withdraw
impl BorshSerialize for Withdraw
Sourceimpl Discriminator for Withdraw
impl Discriminator for Withdraw
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Withdraw
impl InstructionData for Withdraw