pub struct InsuranceFundStake {
pub authority: Pubkey,
pub if_shares: u128,
pub last_withdraw_request_shares: u128,
pub if_base: u128,
pub last_valid_ts: i64,
pub last_withdraw_request_value: u64,
pub last_withdraw_request_ts: i64,
pub cost_basis: i64,
pub market_index: u16,
pub padding: [u8; 14],
}Expand description
Account: InsuranceFundStake
Fields
if_base: u128last_valid_ts: i64last_withdraw_request_value: u64last_withdraw_request_ts: i64cost_basis: i64market_index: u16padding: [u8; 14]Trait Implementations
Sourceimpl AccountDeserialize for InsuranceFundStake
impl AccountDeserialize for InsuranceFundStake
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl BorshDeserialize for InsuranceFundStakewhere
Pubkey: BorshDeserialize,
u128: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
u16: BorshDeserialize,
[u8; 14]: BorshDeserialize,
impl BorshDeserialize for InsuranceFundStakewhere
Pubkey: BorshDeserialize,
u128: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
u16: BorshDeserialize,
[u8; 14]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InsuranceFundStakewhere
Pubkey: BorshSerialize,
u128: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
u16: BorshSerialize,
[u8; 14]: BorshSerialize,
impl BorshSerialize for InsuranceFundStakewhere
Pubkey: BorshSerialize,
u128: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
u16: BorshSerialize,
[u8; 14]: BorshSerialize,
Sourceimpl Clone for InsuranceFundStake
impl Clone for InsuranceFundStake
Sourcefn clone(&self) -> InsuranceFundStake
fn clone(&self) -> InsuranceFundStake
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InsuranceFundStake
impl Default for InsuranceFundStake
Sourcefn default() -> InsuranceFundStake
fn default() -> InsuranceFundStake
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for InsuranceFundStake
impl Discriminator for InsuranceFundStake
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for InsuranceFundStake