pub struct ReferrerName {
pub authority: Pubkey,
pub user: Pubkey,
pub user_stats: Pubkey,
pub name: [u8; 32],
}Expand description
Account: ReferrerName
Fields
user: Pubkeyuser_stats: Pubkeyname: [u8; 32]Trait Implementations
Sourceimpl AccountDeserialize for ReferrerName
impl AccountDeserialize for ReferrerName
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for ReferrerName
impl AccountSerialize for ReferrerName
Sourceimpl BorshDeserialize for ReferrerName
impl BorshDeserialize for ReferrerName
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ReferrerName
impl BorshSerialize for ReferrerName
Sourceimpl Clone for ReferrerName
impl Clone for ReferrerName
Sourcefn clone(&self) -> ReferrerName
fn clone(&self) -> ReferrerName
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ReferrerName
impl Default for ReferrerName
Sourcefn default() -> ReferrerName
fn default() -> ReferrerName
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for ReferrerName
impl Discriminator for ReferrerName
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for ReferrerName