pub struct State {Show 23 fields
pub admin: Pubkey,
pub whitelist_mint: Pubkey,
pub discount_mint: Pubkey,
pub signer: Pubkey,
pub srm_vault: Pubkey,
pub perp_fee_structure: FeeStructure,
pub spot_fee_structure: FeeStructure,
pub oracle_guard_rails: OracleGuardRails,
pub number_of_authorities: u64,
pub number_of_sub_accounts: u64,
pub lp_cooldown_time: u64,
pub liquidation_margin_buffer_ratio: u32,
pub settlement_duration: u16,
pub number_of_markets: u16,
pub number_of_spot_markets: u16,
pub signer_nonce: u8,
pub min_perp_auction_duration: u8,
pub default_market_order_time_in_force: u8,
pub default_spot_auction_duration: u8,
pub exchange_status: u8,
pub liquidation_duration: u8,
pub initial_pct_to_liquidate: u16,
pub padding: [u8; 14],
}Expand description
Account: State
Fields
admin: Pubkeywhitelist_mint: Pubkeydiscount_mint: Pubkeysigner: Pubkeysrm_vault: Pubkeyperp_fee_structure: FeeStructurespot_fee_structure: FeeStructureoracle_guard_rails: OracleGuardRailsnumber_of_sub_accounts: u64lp_cooldown_time: u64liquidation_margin_buffer_ratio: u32settlement_duration: u16number_of_markets: u16number_of_spot_markets: u16signer_nonce: u8min_perp_auction_duration: u8default_market_order_time_in_force: u8default_spot_auction_duration: u8exchange_status: u8liquidation_duration: u8initial_pct_to_liquidate: u16padding: [u8; 14]Trait Implementations
Sourceimpl AccountDeserialize for State
impl AccountDeserialize for State
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for State
impl AccountSerialize for State
Sourceimpl BorshDeserialize for State
impl BorshDeserialize for State
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Statewhere
Pubkey: BorshSerialize,
FeeStructure: BorshSerialize,
OracleGuardRails: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
[u8; 14]: BorshSerialize,
impl BorshSerialize for Statewhere
Pubkey: BorshSerialize,
FeeStructure: BorshSerialize,
OracleGuardRails: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
[u8; 14]: BorshSerialize,
Sourceimpl Discriminator for State
impl Discriminator for State
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for State