Change

Struct Change 

pub struct Change {
    pub paths: Vec<ChangePath>,
    pub changes: Vec<ChangeInfo>,
}
Describes changes detected within a single component or endpoint.

Fields

paths: Vec<ChangePath>

All paths through which this component/endpoint was reached.

For schema changes, this may contain multiple paths if the same schema is referenced from multiple locations. For endpoint changes, this will typically contain a single path.

changes: Vec<ChangeInfo>

Individual changes detected within this component/endpoint.