pub struct FeeStructure {
pub fee_tiers: [FeeTier; 10],
pub filler_reward_structure: OrderFillerRewardStructure,
pub referrer_reward_epoch_upper_bound: u64,
pub flat_filler_fee: u64,
}Fields
fee_tiers: [FeeTier; 10]filler_reward_structure: OrderFillerRewardStructurereferrer_reward_epoch_upper_bound: u64flat_filler_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for FeeStructure
impl BorshDeserialize for FeeStructure
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FeeStructurewhere
[FeeTier; 10]: BorshSerialize,
OrderFillerRewardStructure: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for FeeStructurewhere
[FeeTier; 10]: BorshSerialize,
OrderFillerRewardStructure: BorshSerialize,
u64: BorshSerialize,
Sourceimpl Clone for FeeStructure
impl Clone for FeeStructure
Sourcefn clone(&self) -> FeeStructure
fn clone(&self) -> FeeStructure
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeeStructure
impl Debug for FeeStructure
Sourceimpl Default for FeeStructure
impl Default for FeeStructure
Sourcefn default() -> FeeStructure
fn default() -> FeeStructure
Returns the “default value” for a type. Read more
impl Copy for FeeStructure