pub struct HistoricalOracleData {
pub last_oracle_price: i64,
pub last_oracle_conf: u64,
pub last_oracle_delay: i64,
pub last_oracle_price_twap: i64,
pub last_oracle_price_twap5min: i64,
pub last_oracle_price_twap_ts: i64,
}Fields
last_oracle_price: i64last_oracle_conf: u64last_oracle_delay: i64last_oracle_price_twap: i64last_oracle_price_twap5min: i64last_oracle_price_twap_ts: i64Trait Implementations
Sourceimpl BorshDeserialize for HistoricalOracleData
impl BorshDeserialize for HistoricalOracleData
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for HistoricalOracleData
impl Clone for HistoricalOracleData
Sourcefn clone(&self) -> HistoricalOracleData
fn clone(&self) -> HistoricalOracleData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistoricalOracleData
impl Debug for HistoricalOracleData
Sourceimpl Default for HistoricalOracleData
impl Default for HistoricalOracleData
Sourcefn default() -> HistoricalOracleData
fn default() -> HistoricalOracleData
Returns the “default value” for a type. Read more
impl Copy for HistoricalOracleData