pub struct PoolBalance {
pub scaled_balance: u128,
pub market_index: u16,
pub padding: [u8; 6],
}Fields
scaled_balance: u128market_index: u16padding: [u8; 6]Trait Implementations
Sourceimpl BorshDeserialize for PoolBalance
impl BorshDeserialize for PoolBalance
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PoolBalance
impl BorshSerialize for PoolBalance
Sourceimpl Clone for PoolBalance
impl Clone for PoolBalance
Sourcefn clone(&self) -> PoolBalance
fn clone(&self) -> PoolBalance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PoolBalance
impl Debug for PoolBalance
Sourceimpl Default for PoolBalance
impl Default for PoolBalance
Sourcefn default() -> PoolBalance
fn default() -> PoolBalance
Returns the “default value” for a type. Read more
impl Copy for PoolBalance